@@ -20,9 +20,13 @@
 #include <fcntl.h>
 #include <errno.h>
 
+#include <pthread.h>
+
+typedef int kdev_t;
 #include <linux/md.h>
+#include <linux/raid5.h>
 #include <linux/fs.h>
-#include <linux/kdev_t.h>
+#include <linux/unistd.h>
 
 #define DEBUG				(0)
 #define EXIT_USAGE			(EXIT_FAILURE)
@@ -33,7 +37,11 @@
 #define ZERO_BUFFER_SIZE		(64)	/* 64kB */
 #define MD_BLK_SIZ			(0x400)
 
+extern int do_quiet_flag;
+
 #define MIN(a,b)	((a) < (b) ? (a) : (b))
+#define OUT(x...) do { if (!do_quiet_flag) fprintf(stderr,##x); } while (0)
+#define ERR(x...) fprintf(stderr,##x)
 
 typedef struct md_cfg_entry {
 	md_superblock_t sb, sb_old;
